<?php
/**
 * Exit if accessed directly
 */
if ( !defined( 'ABSPATH' ) ) {
    exit; 
}
if ( !class_exists( 'WordPress_Cooperative_Settings' ) ) {

    class WordPress_Cooperative_Settings {

        public function __construct() {
            global $wpcoop;
            // copy some parameters from wpcoop
            //$this->plugin_version = $wpcoop->plugin_version; // not yet available
            $this->plugin_prefix = $wpcoop->plugin_prefix;
            $this->plugin_textdomain = $wpcoop->plugin_textdomain; 
            $this->plugin_version = $wpcoop->plugin_version; 
            
            $this->plugin_options_page = 'wpcoop_options';

            // when admin initialisation, add settings
            add_action( 'admin_init', array( $this, 'init_options_page' ));
            
            // when in admin menu, add admin pages subpage and settings
            add_action( 'admin_menu', array( $this, 'setup_options_page' ));
            
            
            //to include in parameters
            //$this->pps=100; //  price per share in euro  
            //$this->logo = 'Logo-PEP2A.jpg';
            //$this->signature = 'signature_valide.jpg';
            //$this->company = 'SCIC SAS PEP2A à capital variable';
            //$this->address = "1 avenue Francois Goby\n06460 Saint Vallier de Thiey";
            
            //$this->policies ="Pôle Energ'Ethique des Préalpes d'Azur (PEP2A) SCIC SAS à capital variable immatriculée au RCS de Grasse \nNuméro SIREN 813 177 755\nVous pouvez consulter vos informations sur pep2a.fr/societaires, avec votre identifiant personnel: %s1 ou votre adresse mél %s2, en utilisant éventuellement la procédure de récupération de mot de passe";
        
        }
       /*
        private function get_plugin_version() {
          global $wpcoop;
          return $wpcoop->plugin_version;    
        }
        */
        public function get_possible_statuses() {
        
            return apply_filters ('wpcoop_get_possible_statuses',
                   array('none'=>'Pas de nouvelle opération',
                         'subsnok'=>'Dossier souscription incomplet',
                         'subsok'=>'Dossier souscription complet',
                         'pending'=>'Souscription en attente de validation',
                         // all share relative status must begin with 'share'
                         'shareok'=>'Parts validées'/*, 
                         'sharenok'=>'Rachat de part(s) demandé',
                         'sharenokack'=>'Rachat de part(s) validé',
                         'sharenokexe'=>'Rachat de part(s) exécuté',
                         'sharenokdone'=>'Rachat de part(s) payé'*/
                       ));

        
        }
        
        public function get_possible_actions() {
        
            return apply_filters ('wpcoop_get_possible_actions',
                   array('regsubsnok'=>'Enregistrement dossier souscription incomplet',
                         'delsubs'=>'Suppression souscription',
                         'regsubsok'=>'Energistrement dossier souscription complet',
                         'subsnokok'=>"Validation d'un dossier de souscription incomplet",
                         'subsok'=>"Validation d'un dossier de souscription complet", 
                         'subsokack'=>'Prise en compte du dossier de souscription', 
                         'subswait'=>'Souscription en attente de validation',
                         'shareval'=>'Parts validées',
                         'sharenok'=>'Rachat de part(s) demandé',
                         'sharenokack'=>'Rachat de part(s) validé',
                         'sharenokexe'=>'Rachat de part(s) exécuté',
                         'sharenokdone'=>'Rachat de part(s) payé'
                       ));

        
        }
        
        public function get_workflow() {
            return apply_filters ('wpcoop_get_worflow',
                   array(
                       'none'=>array(
                                    array(                       
                                        'nextstate'=>'subsnok',         // next state possible
                                        'action'=>'regsubsnok',         // action to do
                                        'lib'=> __('Register incomplete application', $this->plugin_textdomain),
                                        'button'=> __('Subs. Nok', $this->plugin_textdomain),
                                        'requires'=>'none',             // status required?
                                        'role'=>''),         // who can do it?
                                    array(
                                        'nextstate'=>'subsok',          // next state possible
                                        'action'=>'regsubsok',          // action to do
                                        'lib'=> __('Register complete application', $this->plugin_textdomain),
                                        'button'=> __('Subs. Ok', $this->plugin_textdomain),
                                        'requires'=>'none',             // status required?
                                        'role'=>'wpcoopadmin'),         // who can do it?
                                      ),
                   
                        'subsnok'=>array(
                                    array(                       
                                        'nextstate'=>'none',       // next state possible
                                        'action'=>'delsubs',             // action to do
                                        'lib'=> __('Supprime le dossier de souscription', $this->plugin_textdomain),
                                        'button'=> __('Delete!', $this->plugin_textdomain),
                                        'requires'=>'none',             // status required?
                                        'role'=>'wpcoopadmin'),         // who can do it?
                                    array(
                                        'nextstate'=>'subsok',          // next state possible
                                        'action'=>'subsnokok',          // action to do
                                        'lib'=> __('Dossier de souscription complété', $this->plugin_textdomain),
                                        'button'=> __('Subs. OK', $this->plugin_textdomain),
                                        'requires'=>'none',             // status required?
                                        'role'=>'wpcoopadmin'),         // who can do it?
                                      ),
                         
                        'subsok'=>array(
                                    array(                       
                                        'nextstate'=>'none',            // next state possible
                                        'action'=>'delsubs',            // action to do
                                        'lib'=> __('Supprime le dossier de souscription', $this->plugin_textdomain),
                                        'button'=> __('Delete!', $this->plugin_textdomain),
                                        'requires'=>'none',             // status required?
                                        'role'=>'wpcoopadmin'),         // who can do it?
                                    array(
                                        'nextstate'=>'pending',       // next state possible
                                        'action'=>'subsokack',        // action to do
                                        'lib'=> __('Dossier de souscription pris en compte', $this->plugin_textdomain),
                                        'button'=> __('Att. Val', $this->plugin_textdomain),
                                        'requires'=>'none',           // status required?
                                        'role'=>'president'),         // who can do it?
                                      ),
                         
                        'pending'=>array(
                                    array(                       
                                        'nextstate'=>'none',         // next state possible
                                        'action'=>'delsubs',         // action to do
                                        'lib'=> __('Supprime le dossier de souscription', $this->plugin_textdomain),
                                        'button'=> __('Delete!', $this->plugin_textdomain),
                                        'requires'=>'none',          // status required?
                                        'role'=>'president'),        // who can do it?
                                    array(
                                        'nextstate'=>'shareok',       // next state possible
                                        'action'=>'sharevala',         // action to do
                                        'lib'=> __('Validation de la souscription par le CA ou l\'AG - nouveau souscripteur -art 15', $this->plugin_textdomain),
                                        'button'=> __('Ok CA/AG', $this->plugin_textdomain),
                                        'requires'=>'none',           // status required?
                                        'role'=>'CA,AG'),             // who can do it? art 15
                            
                                    array(
                                        'nextstate'=>'shareok',       // next state possible
                                        'action'=>'sharevalp',         // action to do
                                        'lib'=> __('Validation de la souscription par le président -souscripteur existant - art 9', $this->plugin_textdomain),
                                        'button'=> __('OK President', $this->plugin_textdomain),
                                        'requires'=>'shareholder',    // status required? art 9
                                        'role'=>'president'),         // who can do it?   art 9
                                      ),
                       
                          'shareok'=>array(
                                    
                                      ),
                     
                       
                                  
/*                        'shareok'=>array(
                                    array(                       
                                        'nextstate'=>'sharenok',         // next state possible
                                        'action'=>'sharereclaim',         // action to do
                                        'lib'=> __('Demande de rachat de part', $this->plugin_textdomain),
                                        'requires'=>'none',          // status required?
                                        'role'=>'shareholder'),        // who can do it?
                                      ),
          
                        'sharenok'=>array(
                                    array(                       
                                        'nextstate'=>'sharenok',         // next state possible
                                        'action'=>'sharereclaim',         // action to do
                                        'lib'=> __('Demande de rachat de part', $this->plugin_textdomain),
                                        'requires'=>'none',          // status required?
                                        'role'=>'shareholder'),        // who can do it?
                                    array(
                                        'nextstate'=>'shareok',       // next state possible
                                        'action'=>'shareval',         // action to do
                                        'lib'=> __('Validation de la souscription par le CA ou l\'AG - nouveau souscripteur -art 15', $this->plugin_textdomain),
                                        'requires'=>'none',           // status required?
                                        'role'=>'CA,AG'),             // who can do it? art 15
                            
                                    array(
                                        'nextstate'=>'shareok',       // next state possible
                                        'action'=>'shareval',         // action to do
                                        'lib'=> __('Validation de la souscription par le président -souscripteur existant - art 9', $this->plugin_textdomain),
                                        'requires'=>'shareholder',    // status required? art 9
                                        'role'=>'president'),         // who can do it?   art 9
                                      ),
            
                        'sharenokack'=>array(
                                    array(                       
                                        'nextstate'=>'sharenok',         // next state possible
                                        'action'=>'sharereclaim',         // action to do
                                        'lib'=> __('Demande de rachat de part', $this->plugin_textdomain),
                                        'requires'=>'none',          // status required?
                                        'role'=>'shareholder'),        // who can do it?
                                    array(
                                        'nextstate'=>'shareok',       // next state possible
                                        'action'=>'shareval',         // action to do
                                        'lib'=> __('Validation de la souscription par le CA ou l\'AG - nouveau souscripteur -art 15', $this->plugin_textdomain),
                                        'requires'=>'none',           // status required?
                                        'role'=>'CA,AG'),             // who can do it? art 15
                            
                                    array(
                                        'nextstate'=>'shareok',       // next state possible
                                        'action'=>'shareval',         // action to do
                                        'lib'=> __('Validation de la souscription par le président -souscripteur existant - art 9', $this->plugin_textdomain),
                                        'requires'=>'shareholder',    // status required? art 9
                                        'role'=>'president'),         // who can do it?   art 9
                                      ),
                        'sharenokexe'=>array(
                                    array(                       
                                        'nextstate'=>'sharenok',         // next state possible
                                        'action'=>'sharereclaim',         // action to do
                                        'lib'=> __('Demande de rachat de part', $this->plugin_textdomain),
                                        'requires'=>'none',          // status required?
                                        'role'=>'shareholder'),        // who can do it?
                                    array(
                                        'nextstate'=>'shareok',       // next state possible
                                        'action'=>'shareval',         // action to do
                                        'lib'=> __('Validation de la souscription par le CA ou l\'AG - nouveau souscripteur -art 15', $this->plugin_textdomain),
                                        'requires'=>'none',           // status required?
                                        'role'=>'CA,AG'),             // who can do it? art 15
                            
                                    array(
                                        'nextstate'=>'shareok',       // next state possible
                                        'action'=>'shareval',         // action to do
                                        'lib'=> __('Validation de la souscription par le président -souscripteur existant - art 9', $this->plugin_textdomain),
                                        'requires'=>'shareholder',    // status required? art 9
                                        'role'=>'president'),         // who can do it?   art 9
                                      ),
                       
                        'sharenokdone'=>array(
                                    array(                       
                                        'nextstate'=>'sharenok',         // next state possible
                                        'action'=>'sharereclaim',         // action to do
                                        'lib'=> __('Demande de rachat de part', $this->plugin_textdomain),
                                        'requires'=>'none',          // status required?
                                        'role'=>'shareholder'),        // who can do it?
                                    array(
                                        'nextstate'=>'shareok',       // next state possible
                                        'action'=>'shareval',         // action to do
                                        'lib'=> __('Validation de la souscription par le CA ou l\'AG - nouveau souscripteur -art 15', $this->plugin_textdomain),
                                        'requires'=>'none',           // status required?
                                        'role'=>'CA,AG'),             // who can do it? art 15
                            
                                    array(
                                        'nextstate'=>'shareok',       // next state possible
                                        'action'=>'shareval',         // action to do
                                        'lib'=> __('Validation de la souscription par le président -souscripteur existant - art 9', $this->plugin_textdomain),
                                        'requires'=>'shareholder',    // status required? art 9
                                        'role'=>'president'),         // who can do it?   art 9
                                      ),
*/                         
                        )
                    );
        }
        
        
        public function setup_options_page() {            
            // add options page (parameters setup)
            add_options_page( __( 'WP Coop setup', $this->plugin_textdomain ),
                              __( 'WP Coop setup', $this->plugin_textdomain ),
                              $this->plugin_capability,
                              $this->plugin_options_page, 
                              array($this, 'display_options_page')
                            );
                       
        }
        // options settings
            
    
        public function get_options_tabs($info='') {
          $medias=array(
                         'tabs'=> array(
                  array( 'slug'=>'coop', 'caption'=>__('Cooperative',$this->plugin_textdomain)),
                  array( 'slug'=>'shares', 'caption'=>__('Shares',$this->plugin_textdomain)),
                  array( 'slug'=>'management', 'caption'=>__('Management',$this->plugin_textdomain)),
                  array( 'slug'=>'councils', 'caption'=>__('Councils',$this->plugin_textdomain)),
                  array( 'slug'=>'meetings', 'caption'=>__('Meetings',$this->plugin_textdomain))
                                       ),
                        'options'=> array(
                  array( 'group'=>$this->plugin_prefix.'options_coop_group', 'name'=>$this->plugin_prefix.'options_coop','callback'=>array($this, 'validate_options_coop')),
                  array( 'group'=>$this->plugin_prefix.'options_shares_group', 'name'=>$this->plugin_prefix.'options_shares','callback'=>array($this, 'validate_options_shares')),
                  array( 'group'=>$this->plugin_prefix.'options_councils_group', 'name'=>$this->plugin_prefix.'options_councils', 'callback'=>array($this, 'validate_options_councils')),
                  array( 'group'=>$this->plugin_prefix.'options_management_group', 'name'=>$this->plugin_prefix.'options_management', 'callback'=>array($this, 'validate_options_management')),
                  array( 'group'=>$this->plugin_prefix.'options_meetings_group', 'name'=>$this->plugin_prefix.'options_meetings', 'callback'=>array($this, 'validate_options_meetings'))
                                         ),
                         'actions'=> array(
                  array( 'slug'=>'coop'),
                  array( 'slug'=>'management')
                                          )
                        );
          $medias=apply_filters('wpcoop_options_tabs',$medias);
          switch($info) {
           case 'tabs':
            $ret=$medias['tabs'];
            break;
           case 'options':
            $ret=$medias['options'];
            break;
           case 'actions':
            $ret=$medias['actions'];
            break;
           default:
            $ret=$medias;
          }
          return $ret;
        } 
        
        
        public function update_secured_image($args) {
            $defs=array('option_group'=>'xxxx',
                        'max_file_size'=>'300000',
                        'name'=>'options_XXXX',
                        'url_option'=>'xxxxx'
                       );
           
            $args=wp_parse_args($args, $defs);
            
            
            settings_fields($this->plugin_prefix.$args['option_group']); 
            ?>
            <input type="hidden" name="MAX_FILE_SIZE" value="<?php echo $args['max_file_size']; ?>" />
            <?php
            $message='';
         
            if (isset($_FILES[$this->plugin_prefix.$args['name']]) && is_array($_FILES[$this->plugin_prefix.$args['name']])) { 
             $tmp=$_FILES[$this->plugin_prefix.$args['name']];
             if (isset($tmp['tmp_name']) && is_file($tmp['tmp_name']) && (!isset($tmp['error']) || $tmp['error']==UPLOAD_ERR_OK)) {   
              if ($r=@fopen($tmp['tmp_name'], "r")) { 
               update_option($this->plugin_prefix.$args['name'],
                                array('name'=>$tmp['name'],
                                      'type'=>$tmp['type'],
                                      'size'=>$tmp['size'],
                                      'data'=>base64_encode(fread($r, $tmp['size']))));
               // TOKEN to be replaced with true token=xxx when url called      
               update_option($this->plugin_prefix.$args['url_option'], get_site_url().'/image/?image='.$args['name'].'&TOKEN&filename='.$tmp['name']);   

              } else {
                $message.=' File not read ';    
              }
             } else {

              if (!isset($tmp['tmp_name']))  {
               $message .= "Temporary file not set";   
              } 
              if (isset($tmp['tmp_name']) && !empty($tmp['tmp_name']) && !is_file($temp['tmp_name']))  {
               $message .= "Temporary file not found";   
              } 

              if (isset($tmp['error']) && $tmp['error']!=0) {
                 switch ($tmp['error']) {
                    case UPLOAD_ERR_INI_SIZE:
                        $message.= "The uploaded file exceeds the upload_max_filesize directive in php.ini";
                        break;
                    case UPLOAD_ERR_FORM_SIZE:
                        $message.= "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form";
                        break;
                    case UPLOAD_ERR_PARTIAL:
                        $message.= "The uploaded file was only partially uploaded";
                        break;
                    case UPLOAD_ERR_NO_FILE:
                        $message.= "No file was uploaded";
                        break;
                    case UPLOAD_ERR_NO_TMP_DIR:
                        $message.= "Missing a temporary folder";
                        break;
                    case UPLOAD_ERR_CANT_WRITE:
                        $message.= "Failed to write file to disk";
                        break;
                    case UPLOAD_ERR_EXTENSION:
                        $message.= "File upload stopped by extension";
                        break;

                    default:
                        $message.= "Unknown upload error";
                        break;
                }                           
              } // error # 
              echo $message;   
             } // read error 
            }
    
        }
        
        // display and permits update of image given by options
        public function display_secured_image_update_form($args) {
            
            $defs=array('option'=>'xxxx',
                        'title'=>__("Image to change",$this->plugin_textdomain),
                        'change'=>__('Change image: ',$this->plugin_textdomain),
                        'name'=>'options_xxxx_file',
                        'update'=>__('Update image',$this->plugin_textdomain)
                       );
            
            $args=wp_parse_args($args, $defs);

            $ar_image=get_option($this->plugin_prefix.$args['option']);
            
            ?>
             <div>
               <table class="form-table">
                <tr>
                    <td><?php echo esc_html($args['title']); ?></td>
                    <td><?php echo (empty($ar_image))? '' : '<img src="data:'.$ar_image['type'].';base64,'.$ar_image['data'].'"/>' ?></td>
                    <td><?php echo esc_html($args['change']); ?>
                     <input type="file" name="<?php echo $this->plugin_prefix.$args['name']; ?>" />
                    </td>
                </tr>
               </table>
               <p class="submit">
                <input type="submit" class="button-primary" value="<?php echo esc_html($args['update']); ?>" />
               </p>
             </div>
            <?php
        }
  
        // Renders the options page. Uses the settings API (options validation, checking and storing by WP).
        public function display_options_page() {
          /////// get active tab
          $tabs= $this->get_options_tabs('tabs');
          $active_tab='coop';
          if( isset( $_GET[ 'tab' ] ) ) {
            foreach($tabs as $tab) {
              if($_GET[ 'tab' ]==$tab['slug']) $active_tab=$tab['slug'];
            }
          }
  
            /////// displays tabs
            ?>
            <div class="wrap">
                <div class="icon32" id="icon-options-general"><br /></div>
                <h2>
                    <?php _e('WpCoop V: '.$this->plugin_version, $this->plugin_textdomain) ?>
                </h2>
                <h2 class="nav-tab-wrapper">
                <?php
                if (!empty($tabs)) {
                  foreach ($tabs as $tab) {
                    $addclass= ($tab['slug']==$active_tab)? 'nav-tab-active' : '';
                    ?>
                    <a href="?page=<?php echo $this->plugin_options_page; ?>&tab=<?php echo $tab['slug']; ?>" class="nav-tab <?php echo $addclass; ?>"><?php echo $tab['caption']; ?> </a>
                    <?php
                  }
                }
                ?>
                </h2>
            </div>
            <?php
            switch ($active_tab) {
                 case 'coop':
                     $options = get_option($this->plugin_prefix.'options_coop');
                    ?>
                    <form method="post" action="options.php" >
                      <?php settings_fields($this->plugin_prefix.'options_coop_group'); ?>
                      <h3><?php _e('Company options', $this->plugin_textdomain) ?></h3>
                      <div>
                        <table class="form-table">
                         <tr>
                            <td><?php _e("Cooperative type",$this->plugin_textdomain) ?></td>
                             <td><select name="<?php echo $this->plugin_prefix.'options_coop[type]'; ?>" >
                                    <option value="scop" <?php echo (isset($options['type']) && $options['type']=='scop')? 'selected="selected"' : '' ?> >SCOP</option>
                                    <option value="scic" <?php echo (isset($options['type']) && $options['type']=='scic')? 'selected="selected"' : '' ?> >SCIC</option>
                                 </select>
                             </td>
                         </tr>
                         <tr>    
                           <td><?php _e("Legal form",$this->plugin_textdomain) ?></td>
                             <td><select name="<?php echo $this->plugin_prefix.'options_coop[form]'; ?>" >
                                    <option value="sa" <?php echo ($options['form']=='sa')? 'selected="selected"' : '' ?> >SA</option>
                                    <option value="sarl" <?php echo ($options['form']=='sarl')? 'selected="selected"' : '' ?> >SARL</option>
                                    <option value="sas" <?php echo ($options['form']=='sas')? 'selected="selected"' : '' ?> >SAS</option>
                                 </select>
                             </td> 
                         </tr>
                         <tr>
                            <td><?php _e("Company name",$this->plugin_textdomain) ?></td>
                            <td><input type="text" name="<?php echo $this->plugin_prefix.'options_coop[name]'; ?>" value="<?php echo esc_attr($options['name']); ?>" /></td>
                         </tr>
                         <tr>
                            <td><?php _e("The xx Company",$this->plugin_textdomain) ?></td>
                            <td><input type="text" name="<?php echo $this->plugin_prefix.'options_coop[embeded_name]'; ?>" value="<?php echo esc_attr($options['embeded_name']); ?>" /></td>
                         </tr>
                         <tr>
                            <td><?php _e("Address",$this->plugin_textdomain) ?></td>
                            <td><input type="text" name="<?php echo $this->plugin_prefix.'options_coop[address]'; ?>" value="<?php echo esc_attr($options['address']); ?>" /></td>
                         </tr>
                         <tr>
                            <td><?php _e("Town",$this->plugin_textdomain) ?></td>
                            <td><input type="text" name="<?php echo $this->plugin_prefix.'options_coop[town]'; ?>" value="<?php echo esc_attr($options['town']); ?>" /></td>
                         </tr>
                         <tr>
                            <td><?php _e("Policies",$this->plugin_textdomain) ?></td>
                            <td><input type="text" name="<?php echo $this->plugin_prefix.'options_coop[policies]'; ?>" value="<?php echo esc_attr($options['policies']); ?>" /></td>
                         </tr>
                         <tr>
                            <td><?php _e("Company Logo name",$this->plugin_textdomain) ?></td>
                            <td><input type="text" name="<?php echo $this->plugin_prefix.'options_coop[logo]'; ?>" value="<?php echo esc_attr($options['logo']); ?>" /></td>
                         </tr>
                        </table>
                        <p class="submit">
                            <input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
                        </p>
                       </div>
                    </form>
                    <form enctype="multipart/form-data" method="post" action="<?php echo admin_url('options-general.php?page=wpcoop_options&tab=coop'); ?>" >
                        <span>Attention: vérifier que le "user_agent" est bien défini, qu'un modèle de page "image" exsite dans votre thème</span>
                        <p></p>
                        <span>Voir votre administrateur</span>
                    <?php 
                    
                    $this->update_secured_image(array('option_group'=>'options_coop_group',
                                                      'max_file_size'=>'300000',
                                                      'name'=>'options_coop_logo_file',
                                                      'url_option'=>'options_coop_logo_url'
                                                ));
 
                    $this->display_secured_image_update_form(array('option'=>'options_coop_logo_file',
                                                                   'title'=>__("Company Logo",$this->plugin_textdomain),
                                                                   'change'=>__('Change logo: ',$this->plugin_textdomain),
                                                                   'name'=>'options_coop_logo_file',
                                                                   'update'=>__('Update Logo',$this->plugin_textdomain)
                                                            ));
                    ?>
                    </form>
                  <?php
                  break;
                 case 'shares':
                    /// display form for shares options
                    $options = get_option($this->plugin_prefix.'options_shares');
                    //print_tab($options);
                    ?>
                    <div>
                      <form method="post" action="options.php">
                        <?php settings_fields($this->plugin_prefix.'options_shares_group'); ?>
                        <h3><?php _e('Shares options', $this->plugin_textdomain) ?></h3>
                        <div>
                         <table class="form-table">
                            <tr>
                            <td><?php _e("Share price",$this->plugin_textdomain) ?></td>
                            <td><input type="text" name="<?php echo $this->plugin_prefix.'options_shares[price]'; ?>" value="<?php echo esc_attr($options['price']); ?>" /></td>
                            </tr>
                         </table>  
                         <p class="submit">
                            <input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
                         </p>
                        </div>  
                       </form>      
                    </div>
                    <?php
                    break;
                case 'management':
                   /// display form for management
                   $options=get_option($this->plugin_prefix.'options_management');
                   $options_coop=get_option($this->plugin_prefix.'options_coop');
                   ?>
                   <div>
                    <form method="post" action="options.php">
                        <?php settings_fields($this->plugin_prefix.'options_management_group'); ?>
                        <h3><?php _e('Management options', $this->plugin_textdomain) ?></h3>
                        <?php if ($options_coop['type']!='scic') { _e('Not yet implemented', $this->plugin_textdomain); break; } ?>
                        <div>
                         <table class="form-table">
                            <?php
                            if ($options_coop['form']=='sa') {
                            ?>    
                            <tr>    
                             <td><?php _e("Management type",$this->plugin_textdomain) ?></td>
                             <td><select name="<?php echo $this->plugin_prefix.'options_management[type]'; ?>" >
                                <option value="1" <?php echo ($options['type']=='1')? 'selected="selected"' : '' ?> >President, Board of Directors, Chief Executive Officer</option>
                                <option value="2" <?php echo ($options['type']=='2')? 'selected="selected"' : '' ?> >Management and Supervisory boards</option>
                                </select>
                             </td> 
                            </tr>
                            <?php
                            }
                            if ($options_coop['form']=='sarl' || $options_coop['form']=='sas' || ($options_coop['form']=='sa' && $options_management['type']=='2')) {
                            ?>    
                            <tr>
                             <td><?php _e("Authority title",$this->plugin_textdomain) ?></td>   
                             <td><input type="text" name="<?php echo $this->plugin_prefix.'options_management[title]'; ?>" value="<?php echo esc_attr($options['title']); ?>" /></td>
                            </tr>
                            <tr>
                             <td><?php _e("Authority name",$this->plugin_textdomain) ?></td>
                             <td><input type="text" name="<?php echo $this->plugin_prefix.'options_management[name]'; ?>" value="<?php echo esc_attr($options['name']); ?>" /></td>
                            <tr>    
                             <td><?php _e("Authority signature",$this->plugin_textdomain) ?></td>
                             <td><input type="text" name="<?php echo $this->plugin_prefix.'options_management[signature]'; ?>" value="<?php echo esc_attr($options['signature']); ?>" /></td>    
                            </tr>
                            <?php   
                            }
                            if ($options_coop['form']=='sarl' || $options_coop['form']=='sas' || ($options_coop['form']=='sa' && $options['type']=='1')) { 
                            ?>
                            <tr>
                             <td><?php _e("Council name",$this->plugin_textdomain) ?></td>   
                             <td><input type="text" name="<?php echo $this->plugin_prefix.'options_management[council_name]'; ?>" value="<?php echo esc_attr($options['council_name']); ?>" /></td>
                            </tr>
                            <tr>
                             <td><?php _e("Short Council name",$this->plugin_textdomain) ?></td>   
                             <td><input type="text" name="<?php echo $this->plugin_prefix.'options_management[short_council_name]'; ?>" value="<?php echo esc_attr($options['short_council_name']); ?>" /></td>
                            </tr>
                            <tr>
                             <td><?php _e("Minimum number of members",$this->plugin_textdomain) ?></td>   
                             <td><input type="text" name="<?php echo $this->plugin_prefix.'options_management[council_min]'; ?>" value="<?php echo esc_attr($options['council_min']); ?>" /></td>
                            </tr>
                            <tr>
                             <td><?php _e("Maximum number of members",$this->plugin_textdomain) ?></td>   
                             <td><input type="text" name="<?php echo $this->plugin_prefix.'options_management[council_max]'; ?>" value="<?php echo esc_attr($options['council_max']); ?>" /></td>
                            </tr>
                            <tr>
                             <td><?php _e("Members must be shareholders",$this->plugin_textdomain) ?></td>   
                             <td><select name="<?php echo $this->plugin_prefix.'options_management[council_shareholders]'; ?>" >
                                <option value="y" <?php echo ($options['council_shareholders']=='y')? 'selected="selected"' : '' ?> ><?php _e('Yes', $this->plugin_textdomain); ?></option>
                                <option value="n" <?php echo ($options['council_shareholders']=='n')? 'selected="selected"' : '' ?> ><?php _e('No', $this->plugin_textdomain); ?></option>
                                </select>
                             </td>    
                            </tr>
                            <tr>    
                             <td><?php _e("Auditor",$this->plugin_textdomain) ?></td>
                             <td><select name="<?php echo $this->plugin_prefix.'options_management[auditor]'; ?>" >
                                <option value="y" <?php echo ($options['auditor']=='y')? 'selected="selected"' : '' ?> ><?php _e('Yes', $this->plugin_textdomain); ?></option>
                                <option value="n" <?php echo ($options['auditor']=='n')? 'selected="selected"' : '' ?> ><?php _e('No', $this->plugin_textdomain); ?></option>
                                </select>
                             </td>    
                            </tr>
                             <tr>    
                             <td><?php _e("Auditor name",$this->plugin_textdomain) ?></td>
                             <td><input type="text" name="<?php echo $this->plugin_prefix.'options_management[auditor_name]'; ?>" value="<?php echo esc_attr($options['auditor_name']); ?>" /></td>    
                            </tr>
                             <tr>    
                             <td><?php _e("Auditor @email",$this->plugin_textdomain) ?></td>
                             <td><input type="text" name="<?php echo $this->plugin_prefix.'options_management[auditor_email]'; ?>" value="<?php echo esc_attr($options['auditor_email']); ?>" /></td>    
                            </tr>
                            <?php 
                            } elseif ($options_coop['type']=='scic' && $options_coop['form']=='sa' && $options['type']=='2') {
                                // management board && supervisory board
                             ?>
                             <tr>
                                 <td colspan="2">option pas encore implantée</td>
                             </tr>
                             <?php
                            }
                            ?>    
                    </table>
                    </div>
                    <p class="submit">
                            <input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
                    </p>
                    </form>
                    <form enctype="multipart/form-data" method="post" action="<?php echo admin_url('options-general.php?page=wpcoop_options&tab=management'); ?>" >
                     <?php
                     $this->update_secured_image(array('option_group'=>'options_management_group',
                                                       'max_file_size'=>'300000',
                                                       'name'=>'options_management_signature_file',
                                                       'url_option'=>'options_management_signature_url'
                                                ));
                     $this->display_secured_image_update_form(array('option'=>'options_management_signature_file',
                                                                   'title'=>__("Authority signature",$this->plugin_textdomain),
                                                                   'change'=>__('Change signature: ',$this->plugin_textdomain),
                                                                   'name'=>'options_management_signature_file',
                                                                   'update'=>__('Update Signature',$this->plugin_textdomain)
                                                             ));
                    ?>
                    </form>
                    <?php
                 break;
                case 'councils':
                   /// display form for meetings
                   global $wpcoop;    
                   $opts_man=get_option($this->plugin_prefix.'options_management');
                   if (empty($opts_man['council_name']) || empty($opts_man['short_council_name'])) {_e('Please set council names',$this->plugin_textdomain); break;}
                   $options=get_option($this->plugin_prefix.'options_councils');
                   $users=$wpcoop->admin->get_ordered_users();
                   ?>
                   <div>
                    <form method="post" action="options.php">
                        <?php settings_fields($this->plugin_prefix.'options_councils_group'); ?>
                        <h3><?php _e('Councils options', $this->plugin_textdomain) ?></h3>
                        <div>
                         <table class="form-table">
                           <?php
                            $i=0; 
                            foreach($options['council_members'] as $i=>$member) {
                             ?><tr>
                                <td><?php _e("Council member",$this->plugin_textdomain) ?></td>
                                <td><?php echo $users[$member['uid']]['display_name']; ?></td>
                                <td><?php _e("Role",$this->plugin_textdomain) ?></td>
                                <td><?php echo esc_html($member['role']); ?></td>    
                                <td><input type="submit" name="<?php echo $this->plugin_prefix.'options_councils[council_members_delete]['.$i.']'; ?>" class="button-secondary" value="<?php _e('Delete') ?>" /></td>    
                             </tr>
                             <?php  
                            }
                            if (count($options['council_members'])<$opts_man['council_max']) {
                            ?>
                            <tr>    
                             <td><?php _e("Add Council member",$this->plugin_textdomain) ?></td>
                             <td><?php $wpcoop->admin->dropdown_users(array('name'=>$this->plugin_prefix.'options_councils[council_members][uid]')); ?></td>    
                             <td><?php _e("Role",$this->plugin_textdomain) ?></td>
                             <td><input type="text" name="<?php echo $this->plugin_prefix.'options_councils[council_members][role]'; ?>" /></td>    
                             <td><input type="submit" name="<?php echo $this->plugin_prefix.'options_councils[council_members_add]'; ?>" class="button-secondary" value="<?php _e('Add') ?>" /></td>    
                            </tr>
                            <?php
                            } elseif (count($options['council_members'])>$opts_man['council_max']) {
                            ?>    
                            <tr>    
                             <td colspan="5" class="message-error"><?php _e("!!! Number is greater than number permitted, delete one or more member(s) !!!",$this->plugin_textdomain) ?></td>
                            </tr>
                            <?php
                            add_settings_error( $this->plugin_prefix.'options_councils', 'number-exeeds', __('Number of members exeeds maximum number.', $this->plugin_textdomain ));

                            }
                            ?>
                         </table>  
                         <p class="submit">
                            <input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
                         </p>
                        </div>  
                   </form>
                   </div>
                   <?php
                 break;
                case 'meetings':
                   /// display form for meetings
                   $options=get_option($this->plugin_prefix.'options_meetings');
                   ?>
                   <div>
                    <form method="post" action="options.php">
                        <?php settings_fields($this->plugin_prefix.'options_meetings_group'); ?>
                        <h3><?php _e('Meetings options', $this->plugin_textdomain) ?></h3>
                        <div>
                         <table class="form-table">
                            <tr>
                            </tr>
                            <tr>
                            <tr>     
                            </tr>
                         </table>  
                         <p class="submit">
                            <input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
                         </p>
                        </div>  
                   </form>
                   </div>
                   <?php
                 break;
            }//switch
        }//display options page
        
        function init_options_page() {
            // get options
            $options=$this->get_options_tabs('options');
            // registers options groups
            foreach($options as $option) {
             register_setting($option['group'],$option['name'],$option['callback']);
            }
        }
        
        public function validate_options_coop($input) {
          wlogt(LOG, '$input', $input);
          foreach($input as $k=>$v) {
           wlog(LOG, $k);   
           if ($k=='logo_file') {
               
               wlogt(LOG, '$_FILES', $_FILES);
               
           } else {     
            if (!is_string($v)) $input[$k]= (string) $v;  
            if ($k=='type' && !in_array($v, array('scic','scop')))  $input[$k]='scop';      
            if ($k=='form' && !in_array($v, array('sa','sarl', 'sas')))  $input[$k]='sa'; 
           }
          }  
            
          return apply_filters($this->plugin_prefix.'validate_options_coop', $input);  
        }
        
        public function validate_options_shares($input) {
          foreach($input as $k=>$v) {
            if (!is_string($v)) $input[$k]= (string) $v;  
          }  
          $input['price']= ($input['price']==0 || empty($input['price']) || intval($input['price'])!=$input['price'])? 100 : $input['price'];
          return apply_filters($this->plugin_prefix.'validate_options_shares', $input); 
        }
        
        public function validate_options_management($input) {
          foreach($input as $k=>$v) {
              if (!is_string($v)) $input[$k]= (string) $v;

              if ( $k== 'council_min' || $k== 'council_max') {
                    $input[$k]= (string) absint($v);
              }
              if ( $k== 'council_min' && isset($input['council_min']) && isset($input['council_max']) && !( absint($input['council_max'])+1 > absint($input['council_min']) ) ) {
                 add_settings_error( $this->plugin_prefix.'options_management', 'invalid-council', __("Maximum number must be greater or equal to minimum", $this->plugin_textdomain ));
                 $input['council_min']=absint($input['council_max']);
              }
              if ( $k== 'council_shareholders' && $input['council_shareholders']!='y' && $input['council_shareholders']!='n'){
                 add_settings_error( $this->plugin_prefix.'options_management', 'invalid-council', __("Choice must be Yes or No", $this->plugin_textdomain ));
                 $input[$k]='y'; 
              }
              
              if ( $k== 'auditor' && $input['auditor']!='y' && $input['auditor']!='n'){
                 add_settings_error( $this->plugin_prefix.'options_management', 'invalid-auditor', __("Auditor choice must be Yes or No", $this->plugin_textdomain ));
                 $input[$k]='y'; 
              }
              if ( $k== 'auditor' && $input['auditor']=='y' && (empty($input['auditor_name']) || empty($input['auditor_email']) )) {
                 add_settings_error( $this->plugin_prefix.'options_management', 'invalid-auditor', __("Auditor name or email can't be empty.", $this->plugin_textdomain ));
               }
              if ( $k== 'auditor_email' && !is_email($v) ) {
                if (!empty($input['auditor_name']) && !empty($v)) {  
                 add_settings_error( $this->plugin_prefix.'options_management', 'invalid-email', __('You have entered an invalid e-mail address.', $this->plugin_textdomain ));
                }
                $input[$k]='';  
              } 
          }  
          return apply_filters($this->plugin_prefix.'validate_options_management', $input); 
        }
        
        public function validate_options_meetings($input) {
          foreach($input as $k=>$v) {
            if (!is_string($v)) $input[$k]= (string) $v;  
          }  
            
          return apply_filters($this->plugin_prefix.'validate_options_meetings', $input); 
        }
        
        public function validate_options_councils($input) {
          $opts_man=get_option($this->plugin_prefix.'options_management');
          $options=get_option($this->plugin_prefix.'options_councils'); 
          // delete council member     
          if (isset($input['council_members_delete'])) {
                unset ($options['council_members'][intval(key($input['council_members_delete']))] );
          } elseif (isset($input['council_members_add'])) { 
          // add council member
            //@TODO verify uid is ok (existing user or partner) && uid is not already present
            $isin=false;  
            foreach($options['council_members'] as $m) {
                if ($m['uid']==intval($input['council_members']['uid'])) {
                    $isin=true;
                }
            } 
            if (count($options['council_members'])<$opts_man['council_max'] && !$isin) {
              $options['council_members'][]=array('role' => (string) $input['council_members']['role'], 'uid'=>intval($input['council_members']['uid']));
            } else {
              if(count($options['council_members'])==$opts_man['council_max']) {
                  add_settings_error( $this->plugin_prefix.'options_councils', 'council_max_exceeded', __('Maximum number of members exceeded.', $this->plugin_textdomain ));
              }
              if ($isin) {
                  add_settings_error( $this->plugin_prefix.'options_councils', 'user_isin', __('Already member of council.', $this->plugin_textdomain ));
              }
            }
          }
          return apply_filters($this->plugin_prefix.'validate_options_councils', $options); 
        }
    } // end class
} // end if class exists