<?php
/*
Plugin Name: WpCoounters
Plugin URI: http://pep2a.fr/
Description: WpCoounters plugin is here to add counters
Version: 0.0
Author: alain messin
*/

/*  Copyright 2017 pep2a 

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/**
 * Exit if accessed directly
 */
if ( !defined( 'ABSPATH' ) ) {
    exit; 
}

/**
 * Base class
 */
if ( !class_exists( 'WordPress_Coounters' ) ) {

    final class WordPress_Coounters {
    
        public static $plugin_prefix;
        public static $plugin_url;
        public static $plugin_path;
        public static $plugin_basefile;
        public static $plugin_basefile_path;
        public static $plugin_textdomain;

        public $docs_params;

        public $plugin_version;
        public $writepanel;
        public $settings;
        public $print;
        public $docs;
        public $theme;

        /**
         * Constructor
         */
        public function __construct() {
            // defines some variables

            $this->plugin_prefix = 'wpcoounters_';
            $this->plugin_basefile_path = __FILE__;
            $this->plugin_basefile = plugin_basename( $this->plugin_basefile_path );
            $this->plugin_url = plugin_dir_url( $this->plugin_basefile );
            $this->plugin_includes = $this->plugin_url.'includes/';
            $this->plugin_js = $this->plugin_includes.'js/';
            
            $this->plugin_path = trailingslashit( dirname( $this->plugin_basefile_path ) );
            $this->plugin_textdomain = 'wpcoounters' ;
            
            $this->plugin_pdf_path = WP_PLUGIN_DIR. '/wpcoounters/'; 
                        
            add_action( 'init', array( $this, 'plugin_init' ) );
            
            add_action( 'wp_enqueue_scripts', array($this, 'add_odometer_stuff'));
            
            add_action( 'admin_enqueue_scripts', array($this, 'add_odometer_stuff'));
            
        }
        
        public function add_odometer_stuff() {        
            $counters=apply_filters($this->plugin_prefix.'read_site_counters', get_option($this->plugin_prefix.'site_counters'));
            if (empty($counters)) { 
                $counters=array(
                          array('date'=>date('Ymd'), 'digits'=>6, 'value'=>33528, 'valueBackColor'=> "#fe3355"),
                          array('date'=>date('Ymd'), 'digits'=>4, 'value'=>42),
                          array('date'=>date('Ymd'), 'digits'=>5, 'value'=>256, height=>20)
                              );
                update_option($this->plugin_prefix.'site_counters', $counters);
            }
                        
            wp_enqueue_script( 'wpcoounters', $this->plugin_js.'wpcoounters.js', array('jquery') );
            wp_enqueue_script( 'wpcoounters_site', $this->plugin_js.'wpcoounters_site.js', array('jquery','wpcoounters' ));
            wp_localize_script('wpcoounters_site', $this->plugin_prefix.'site_counters', $counters );          

        }
      
        public function plugin_version() {
            if(function_exists('get_plugin_data')) {
                $plugin_data = get_plugin_data( __FILE__ );
               return $plugin_data['Version'];
            } else {
                return '0.0';
            }
        }       
        
        public function plugin_init() {
            
            // Internationalize the plugin
            $this->localise();
            // Load includes
            $this->includes();
            // load resources (js, css, aso...)
            $this->load_resources();
            
            // get version
            $new_version=$this->plugin_version();
            $old_version=get_option($this->plugin_prefix.'plugin_version');
            // update if new version
            // cancel plugin if previous
            // @TODO Error message
            if($this->is_later_version($new_version, $old_version)) {
              $this->update($new_version,$old_version);   
              update_option($this->plugin_prefix.'plugin_version', $new_version );  
            } elseif ($this->is_previous_version($new_version, $old_version)) {
              //@TODO manage old versions    
              return;    
            }
            $this->plugin_version=$new_version;  
            
            // settings must be in first position
            //$this->settings= new WordPress_Cooperative_Settings;
            //$this->admin= new WordPress_Cooperative_Admin;
            
            // add shorcode
            add_shortcode($this->plugin_prefix.'sc', array($this,'sc_handler') );
            
        }
        
        // short code handler
        public function sc_handler($atts) {

            $a = shortcode_atts( array(
                                 'type' => 'odometer',
                                 'container' => 'div',
                                 'containerclasses' => '',
                                 'height'=>50,
                                 'blogid' => get_current_blog_id(),
                                 'blogoption'=> '',
                                 'optionindex'=> 'value',
                                 'counterindex'=>0,
                                 'updateinterval' =>0,
                                 'settimeglobal'=>0,
                                 'settimedigit'=>0,
                                 'maxvalue'=>10,
                                 'minvalue'=>0,
                                 'legend'=>"Target",

                                 // odometer original parameters (lowered case)   
                                 'digits'=>6,
                                 'decimals'=>0,
                                 'decimalbackcolor'=> '#F0F0F0',
                                 'decimalforecolor'=> '#F01010',
                                 'font'=>'sans-serif',
                                 'value'=>0,
                                 'valuebackcolor'=>'#050505',
                                 'valueforecolor'=>'#F8F8F8',
                                 'wooblefactor'=>0.2,
                                      ), $atts );
            
            // filters values
            $a['height']= intval($a['height']);
            $a['blogid']= intval($a['blogid']);
            $a['counterindex']= intval($a['counterindex']);
            
            
            if (!empty($a['blogoption'])) {
              $option=get_blog_option($a['blogid'], $a['blogoption']);
              if (is_array($option) && isset($option[$a['optionindex']]) ) {
                 $a['value']=$option[$a['optionindex']];                  
              }
                
                
                
            }
           
            return '<'.$a['container'].' class="wpcoounters '.$a['containerclasses'].'" '.
                   // appearance
                   'data-type="'.$a['type'].'" '.
                   'data-container="'.$a['container'].'" '.
                   'data-containerclasses="'.$a['containerclasses'].'" '.
                   'data-height="'.$a['height'].'" '.
                   'data-maxvalue="'.$a['maxvalue'].'" '.
                   'data-minvalue="'.$a['minvalue'].'" '.
                   'data-legend="'.$a['legend'].'" '.
                
                   //source of data and timings
                   'data-blogid="'.$a['blogid'].'" '.
                   'data-blogoption="'.$a['blogoption'].'" '.
                   'data-blogoption="'.$a['blogoption'].'" '.
                   'data-counterindex="'.$a['counterindex'].'" '.
                   'data-updateinterval="'.$a['updateinterval'].'" '.
                   'data-settimeglobal="'.$a['settimeglobal'].'" '.
                   'data-settimedigit="'.$a['settimedigit'].'" '.
                   
                   // odometer original parameters (lowered case)   
                    //'data-height="'.$a['height'].'" '.
                   'data-digits="'.$a['digits'].'" '.
                   'data-decimals="'.$a['decimals'].'" '.
                   'data-decimalbackcolor="'.$a['decimalbackcolor'].'" '.
                   'data-decimalforecolor="'.$a['decimalforecolor'].'" '.
                   'data-font="'.$a['font'].'" '.
                   'data-value="'.$a['value'].'" '.
                   'data-valuebackcolor="'.$a['valuebackcolor'].'" '.
                   'data-valueforecolor="'.$a['valueforecolor'].'" '.
                   'data-wooblefactor="'.$a['wooblefactor'].'" '.    
                   '></'.$a['container'].'>';
        }
        
        public function localise() {
            // Load language files from the plugin folder  
            load_plugin_textdomain( $this->plugin_textdomain, false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
            //load_plugin_textdomain('wp-fullcalendar', false, dirname( plugin_basename( __FILE__ ) ).'/includes/langs');
            // Internationalize the plugin with possibility to change locale
            //$locale = apply_filters( 'plugin_locale', get_locale(), $this->plugin_textdomain);
            //load_textdomain($this->plugin_textdomain, $this->plugin_path . 'languages/.$this->plugin_textdomain.'-'.$locale.'.mo');
        }
        
        public function load_resources() {
        }
        
        
        
        public function includes() {
            //include_once( 'includes/class-wpcoounters-settings.php' );
            //include_once( 'includes/class-wpcoounters-admin.php' );
        }
        
        private function is_later_version($new, $old) {
            
          return $new>$old;  
        }
        
        private function is_previous_version($new, $old) {
            
          return false;  
        }
        
        private function update($new, $old) {
            
            
        }


   } //end of WordPress_Cooperative class
}// if exists WordPress_Cooperative class

// create instance
$wpcoot = new WordPress_Coounters;


